
module WeighflowCli 
  class CliWeights < Thor
    include Rendering

    desc 'from_index [INDEX ID]', 'create weight from index'
    #option :index, required: true, banner: 'ie. CommodityOrder-T-I-002-3340455-01'
    option :gross, aliases: '-g', type: :numeric, required: true
    option :tare, aliases: '-t', type: :numeric, required: true
    option :certificate, aliases: '-c', required: true
    def from_index(index_id)
      raise 'index_id required' unless index_id
      index = WeighflowCli.find_order(index_id)
      raise 'index not found for id' unless index && index.data
      #
      # parse external id parts
      order_type, transport, io, location, order_num, lin =  index.data[:external_unique_id].to_s.split('-')
      #
      # correct for diff in type between order and weight processor
      order_type = 'Inventory' if order_type == 'BulkInventory'
      #
      weight_params = {
        io: index.data[:i_o],
        order_id: index.data[:order_id],
        order_type: order_type,
        gross_weight: options[:gross].to_i,
        tare_weight: options[:tare].to_i,
        weighed_at: Time.now.round,
        certificate_number: options[:certificate].to_s
      }

      options_renderer(WeighflowCli.create_weight(params: weight_params), options) 
    end


    desc 'template [INDEX_ID]', 'create weight template'
    def template(index_id)
      aise 'index_id required' unless index_id
      index = WeighflowCli.find_order(index_id)
      raise 'index not found for id' unless index && index.data
      #
      # parse external id parts
      order_type, transport, io, location, order_num, lin =  index.data[:external_unique_id].to_s.split('-')
      #
      # correct for diff in type between order and weight processor
      order_type = 'Inventory' if order_type == 'BulkInventory'
      #
      weight_params = {
        io: index.data[:i_o],
        order_id: index.data[:order_id],
        order_type: order_type,
        gross_weight: 0,
        tare_weight: 0,
        weighed_at: Time.now.round,
        certificate_number: "{cert number}"
      }
      options_renderer(weight_params, options) 
    end

    
    desc 'list', 'List weights within the last 24 hours'    
    def list
      options_renderer(WeighflowCli.weights, options) 
    end



    desc 'create', 'Create a weight given an order'   
    long_desc <<~DESC

      weighflow_cli --file weight.json

      This file should contain a minimum of :

      { 
        order_type: "Commodity", 
        io: "O", 
        order_id: "{integer}", 
        gross_weight: "75000", 
        tare_weight: "25444", 
        weighed_at: "2021-02-26 10:15:41 am", 
        release_number: "", 
        truck_license_number: "", 
        trailer1_license_number: "", 
        trailer2_license_number: "", 
        truck_number: "", 
        driver_name: "", 
        driver_number: "" 
      }
    
    --
    DESC
    option :file, aliases: '-f',  required: true, banner: '[File name] json format'
    def create 
      weight_params = JSON.parse(File.read(options[:file]), symbolize_names: true)
      puts weight_params
      
      options_renderer(WeighflowCli.create_weight(params: weight_params), options) 
      #options_renderer(options, options) 
    end


    desc 'void', 'Voided a weight within 24 hours'
    option :weight_id, required: true
    option :reason, required: true
    def void 
      options_renderer(WeighflowCli.void_weight(options[:weight_id], options[:reason]), options) 
    end
    
  end
end
