module WeighflowCli

  class Client
    include HTTParty
    debug_output $stdout if ENV['DEBUG']

    def initialize(config = {})       
      self.class.headers auth_headers(config[:secret].to_s)
      self.class.base_uri config[:url].to_s
    end

    def auth_headers(token)
      { 'Authorization' =>  "Token #{token}"}
    end

    
    def status
      response = self.class.get('/')        
      render_json(response)
    end

    def create_weight(params: {})
      response = self.class.post('/weights', body: params)    
      render_json(response)     
    end

    def void_weight(weight_id, reason)
      response = self.class.delete("/weights/#{weight_id}", body: { reason: reason })    
      render_json(response)
    end

    def weights
      response = self.class.get('/weights')    
      render_json(response)
    end


    def commodity_outbound_truck       
      find_orders(selection: 'OC')    
    end

    def commodity_inbound_truck
      find_orders(selection: 'IC') 
    end

    def bulk_inventory_inbound_truck
      find_orders(selection: 'II')      
    end
 

    def bulk_inventory_outbound_truck
      find_orders(selection: 'OI')      
    end


    private

    def find_orders(selection: 'OC')
      response = self.class.get('/orders', query: { s: selection })           
      render_json(response)
    end
 
    def render_error(response)
      raise Error, "Problem accessing Weighflow API #{response.code} : #{response.body}" 
    end

    def render_json(response)
      render_error(response) unless response.success?  
      JSON.parse(response.body, symbolize_names: true)
    end

  end

end